%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                        %
%           TEST OF PARTIAL IDENTIFICATION OF PARAMETERS                 %
%           MODEL OF LONG TERM CARE FOR ELDERLY PARENTS                  %
%                                                                        %
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


% This page provides the interface for running a test of partial
% identification of parameters for the family bargaining model of long term
% care decision for elderly parents.
%
% The basic model is that of Engers and Stern (2002) and the procedure of
% estimation has been proposed by Henry Meango Queyranne (2014)
%
% The interface includes the following program:
%   - "spec_rest.m" regroup the restrictions that we can use for testing.
%
%   - "get_x_y.m" retrieves the correct formulation of the variables.
%
%   - "n_param_inc_PHAT.m" computes the observed probabilities and increase them from
%     PHAT to PHAT_bar s.t. Pr(PHAT_bar<PHAT)=1-alpha.
%     
% The outcome are transferred to C for computation of the confidence region.
%
% The last section contains the commands for plotting the convex hull and
% slices of the confidence region.


%% Initialisation

nb.max_player = 2;  % Maximum number of children in the sample
nb.opt_dir    = 2;  % Number of options different from care provided by one child
nb.eql        = 2^nb.max_player;          % Number of equilibria
nb.option     = nb.max_player+nb.opt_dir; % Total number of options
nb.N          = 2;

%------------------------------------------------------------
% Specification and restrictions
%------------------------------------------------------------

% By entering "spec_rest.m", you can change several parameters for the
% test.
%  - Include or exclude some explanatory variables.
%  - Fix the number of children in the family
%  - Change the estimation of PHAT from multinomial, non parametrical,
%    smoothed non parametrical.

%% Restrictions for fondamental model
[restr,nb,p_name] = spec_rest(nb);

%------------------------------------------------------------
% Test Configuration
%------------------------------------------------------------

nb.tolerance = 0;    % Tolerance of rejected markets
nb.conf_level= 0.95;    % Confidence level
nb.boot_count= 999; % number of bootstrap replications


%% Load the matrix of data

load care_data.mat
[Xplic, X]= get_x_y(A_data,restr,nb);

nb.obs   = length (X(:,1));
nb.dim_x = length (X(1,:));


%% Compute the observed probabilities

    [PHAT,PHAT_bar, grid,x_eq]=n_param_inc_PHAT(X,Xplic.Y,nb);
    %load PHAT_bar.mat % To use if you have already computed PHAT_bar.

%% Transfer to C in format mrkt x equilbrium
nb.lgrid=length(grid(:,1));
% Transform the vector to show only the relevant inequalities
P = zeros(nb.lgrid,length(PHAT(1,:)));
for giter = 1:nb.lgrid
    P(giter,:) = PHAT_bar(x_eq(giter).Index(1),:);
end

% In format equilbrium
eql=[0 0 0 0;
    1 0 0 0;
    0 1 0 0;
    0 0 1 0;
    0 0 0 1;
    1 1 0 0;
    1 0 1 0;
    1 0 0 1;
    0 1 1 0;
    0 1 0 1;
    0 0 1 1;
    1 1 1 0;
    1 1 0 1;
    1 0 1 1;
    0 1 1 1;
    1 1 1 1];

Proba = (eql*P')';

% Transfer: Define target for the "C folder"
    binifile(Proba, 'C:\cygwin\home\MEANGO\care_ind\proba.bin','double')
    binifile(grid, 'C:\cygwin\home\MEANGO\care_ind\xpli.bin','double')  

%% Plotting Theta
lr=2;
d=12;
filename = 'C:\cygwin\home\Romu\care_ind\Theta_result.bin';
Theta = readifile(filename,[lr,d],'double');
A=[min(Theta,[],1)' max(Theta,[],1)']

 Theta_temp = Theta_v;
 Theta_v = vertcat(Theta_temp,Theta);
    %--------------------------------------------------------
    %Draw the points or the polyhedron
    %--------------------------------------------------------
    t_ax1 = [1 2 3];
    t_ax2 = [1 2 7];
    t_ax3 = [1 3 7];
    t_ax4 = [2 3 7];

    subplot(2,2,1);
    plot(hull(unique(Theta(:,t_ax1),'rows')))
    xlabel(p_name.psave(t_ax1(1),:));
    ylabel(p_name.psave(t_ax1(2),:));
    zlabel(p_name.psave(t_ax1(3),:));

    subplot(2,2,2);
    plot(hull(unique(Theta(:,t_ax2),'rows')))
    xlabel(p_name.psave(t_ax2(1),:));
    ylabel(p_name.psave(t_ax2(2),:));
    zlabel(p_name.psave(t_ax2(3),:));

    subplot(2,2,3);
    plot(hull(unique(Theta(:,t_ax3),'rows')))
    xlabel(p_name.psave(t_ax3(1),:));
    ylabel(p_name.psave(t_ax3(2),:));
    zlabel(p_name.psave(t_ax3(3),:));

    subplot(2,2,4);
    plot(hull(unique(Theta(:,t_ax4),'rows')))
    xlabel(p_name.psave(t_ax4(1),:));
    ylabel(p_name.psave(t_ax4(2),:));
    zlabel(p_name.psave(t_ax4(3),:));
    
    clear t_ax*
 
%% Slice of confidence region
 % \beta_{00} = 1
 
 t_ax = [1 2 3];
 h = figure;
 Pol=hull(unique(Theta_eqv(:,t_ax),'rows'));
 plot(slice(Pol,1,1))
 xlabel('\beta_{ah}');
 ylabel('\beta_{ac} = -\beta_m');
 filename = 'C:\Users\Public\care_ind\CI\2d_bah_bac.eps';
 print(h,'-depsc',filename)
 filename = 'C:\Users\Public\care_ind\CI\2d_bah_bac';
 print(h,'-dpdf',filename)

  t_ax = [1 2 7];
 h = figure;
 Pol=hull(unique(Theta_hlfv(:,t_ax),'rows'));
 plot(slice(Pol,1,1))
 xlabel('\beta_{ah}');
 ylabel('\psi_s');
 axis([-10 0 0 5])
 filename = 'C:\Users\Public\care_ind\CI\2d_bah_psis.eps';
 print(h,'-depsc',filename)
  filename = 'C:\Users\Public\care_ind\CI\2d_bah_psis';
 print(h,'-dpdf',filename)
 
  t_ax = [1 2 8];
 h = figure;
 Pol=hull(unique(Theta_hlfv(:,t_ax),'rows'));
 plot(slice(Pol,1,1))
 xlabel('\beta_{ah}');
 ylabel('\psi_d');
  axis([-10 0 -10 0])
 filename = 'C:\Users\Public\care_ind\CI\2d_bah_psid.eps';
 print(h,'-depsc',filename)
  filename = 'C:\Users\Public\care_ind\CI\2d_bah_psid';
 print(h,'-dpdf',filename)
 
  t_ax = [1 3 7];
 h = figure;
 Pol=hull(unique(Theta_hlfv(:,t_ax),'rows'));
 plot(slice(Pol,1,1))
 xlabel('\beta_{ac} = -\beta_m');
 ylabel('\psi_s');
 axis([-10 0 0 5])
 filename = 'C:\Users\Public\care_ind\CI\2d_bm_psis.eps';
 print(h,'-depsc',filename)
  filename = 'C:\Users\Public\care_ind\CI\2d_bm_psis';
 print(h,'-dpdf',filename)
 
  t_ax = [1 3 8];
 h = figure;
 Pol=hull(unique(Theta_hlfv(:,t_ax),'rows'));
 plot(slice(Pol,1,1))
 xlabel('\beta_{ac} = -\beta_m');
 ylabel('\psi_d');
  axis([-10 0 -10 0])
 filename = 'C:\Users\Public\care_ind\CI\2d_bm_psid.eps';
 print(h,'-depsc',filename)
  filename = 'C:\Users\Public\care_ind\CI\2d_bm_psid';
 print(h,'-dpdf',filename)
 
  t_ax = [1 7 8];
 h = figure;
 Pol=hull(unique(Theta_hlfv(:,t_ax),'rows'));
 plot(slice(Pol,1,1))
 xlabel('\psi_s');
 ylabel('\psi_d');
 axis([0 5 -10 0])
 filename = 'C:\Users\Public\care_ind\CI\2d_psis_psid.eps';
 print(h,'-depsc',filename)
  filename = 'C:\Users\Public\care_ind\CI\2d_psis_psid';
 print(h,'-dpdf',filename)


